<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>CalendarWindow</name>
    <message>
        <location filename="../calendarwindow.cpp" line="203"/>
        <source>First Day of Week</source>
        <translation>Први дан седмице</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="40"/>
        <source>Deepin Calendar</source>
        <translation>Дипин Календар</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>Calendar is a date tool.</source>
        <translation>Календар је алат за приказивање датума.</translation>
    </message>
</context>
<context>
    <name>InfoView</name>
    <message>
        <location filename="../infoview.cpp" line="24"/>
        <source>Today</source>
        <translation>Данас</translation>
    </message>
</context>
</TS>